@@ -29,9 +29,11 @@ check_params = function(params_sleep = c(), params_metrics = c(),
   }
   #-----------------------------------------------------------------------------------------
   if (length(params_sleep) > 0) { # Check class of sleep parameters
-    numeric_params = c("anglethreshold", "timethreshold", "longitudinal_axis", "possible_nap_window", "possible_nap_dur",
-                       "colid", "coln1", "def.noc.sleep", "nnights", "sleepefficiency.metric", "possible_nap_edge_acc")
-    boolean_params = c("ignorenonwear", "constrain2range", "HASPT.ignore.invalid",
+    numeric_params = c("anglethreshold", "timethreshold", "longitudinal_axis", 
+                       "possible_nap_window", "possible_nap_dur",
+                       "colid", "coln1", "def.noc.sleep", "nnights", 
+                       "sleepefficiency.metric", "possible_nap_edge_acc", "HDCZA_threshold")
+    boolean_params = c("ignorenonwear", "HASPT.ignore.invalid",
                        "relyonguider", "sleeplogidnum")
     character_params = c("HASPT.algo", "HASIB.algo", "Sadeh_axis", "nap_model",
                          "sleeplogsep", "sleepwindowType", "loglocation")
